@@ -5,6 +5,7 @@ import sys
 
 from io import StringIO
 
+from typing import List
 from typing import Optional
 from typing import TextIO
 
@@ -35,7 +36,7 @@ RE_CAPTURE = re.compile(r"^\w[a-zA-Z0-9_\-]*$")
 TAG_CAPTURE = sys.intern("capture")
 TAG_ENDCAPTURE = sys.intern("endcapture")
 
-ENDCAPTUREBLOCK = (TAG_ENDCAPTURE, TOKEN_EOF)
+ENDCAPTUREBLOCK = frozenset((TAG_ENDCAPTURE, TOKEN_EOF))
 
 
 class CaptureNode(ast.Node):
@@ -64,7 +65,7 @@ class CaptureNode(ast.Node):
         buf = StringIO()
         self.block.render(context, buf)
         self._assign(context, buf)
-        return None
+        return False
 
     async def render_to_output_async(
         self, context: Context, buffer: TextIO
@@ -72,7 +73,16 @@ class CaptureNode(ast.Node):
         buf = StringIO()
         await self.block.render_async(context, buf)
         self._assign(context, buf)
-        return None
+        return False
+
+    def children(self) -> List[ast.ChildNode]:
+        return [
+            ast.ChildNode(
+                linenum=self.tok.linenum,
+                node=self.block,
+                template_scope=[self.name],
+            )
+        ]
 
 
 class CaptureTag(Tag):
