@@ -1,4 +1,5 @@
 """Test math filter functions."""
+# pylint: disable=too-many-public-methods,too-many-lines,missing-class-docstring
 import unittest
 
 from functools import partial
@@ -10,6 +11,8 @@ from typing import List
 from typing import Dict
 
 from liquid.environment import Environment
+from liquid.expression import NIL
+
 
 from liquid.exceptions import Error
 from liquid.exceptions import FilterError
@@ -77,7 +80,7 @@ class ArrayFilterTestCase(unittest.TestCase):
                     "#",
                 ],
                 kwargs={},
-                expect=FilterValueError,
+                expect="a, b",
             ),
             Case(
                 description="lists of integers",
@@ -114,7 +117,7 @@ class ArrayFilterTestCase(unittest.TestCase):
                 val=12,
                 args=[", "],
                 kwargs={},
-                expect=FilterValueError,
+                expect="12",
             ),
             Case(
                 description="value array contains non string",
@@ -178,7 +181,7 @@ class ArrayFilterTestCase(unittest.TestCase):
                 val=12,
                 args=[],
                 kwargs={},
-                expect=FilterValueError,
+                expect=None,
             ),
             Case(
                 description="first of undefined",
@@ -228,7 +231,7 @@ class ArrayFilterTestCase(unittest.TestCase):
                 val=12,
                 args=[],
                 kwargs={},
-                expect=FilterValueError,
+                expect=None,
             ),
             Case(
                 description="last of undefined",
@@ -278,7 +281,7 @@ class ArrayFilterTestCase(unittest.TestCase):
                 val="a, b",
                 args=[["c", "d"]],
                 kwargs={},
-                expect=FilterValueError,
+                expect=["a, b", "c", "d"],
             ),
             Case(
                 description="array contains non string",
@@ -335,14 +338,14 @@ class ArrayFilterTestCase(unittest.TestCase):
                 val=[{"title": "foo"}, {"title": "bar"}, {"heading": "baz"}],
                 args=["title"],
                 kwargs={},
-                expect=["foo", "bar", None],
+                expect=["foo", "bar", NIL],
             ),
             Case(
                 description="value not an array",
                 val=123,
                 args=["title"],
                 kwargs={},
-                expect=FilterValueError,
+                expect=FilterError,
             ),
             Case(
                 description="array contains non object",
@@ -363,7 +366,7 @@ class ArrayFilterTestCase(unittest.TestCase):
                 val=[{"title": "foo"}, {"title": "bar"}, {"title": "baz"}],
                 args=[self.env.undefined("test")],
                 kwargs={},
-                expect=[None, None, None],
+                expect=[NIL, NIL, NIL],
             ),
         ]
 
@@ -506,7 +509,7 @@ class ArrayFilterTestCase(unittest.TestCase):
                 val=["b", "a", None, "C", "B", "A"],
                 args=[],
                 kwargs={},
-                expect=[None, "a", "A", "b", "B", "C"],
+                expect=["a", "A", "b", "B", "C", None],
             ),
             Case(
                 description="lists of objects with key",
@@ -555,7 +558,7 @@ class ArrayFilterTestCase(unittest.TestCase):
                 val=[{"title": "foo"}, {"title": "bar"}, {"title": "Baz"}],
                 args=[self.env.undefined("test")],
                 kwargs={},
-                expect=[{"title": "foo"}, {"title": "bar"}, {"title": "Baz"}],
+                expect=[{"title": "bar"}, {"title": "Baz"}, {"title": "foo"}],
             ),
         ]
 
@@ -584,7 +587,7 @@ class ArrayFilterTestCase(unittest.TestCase):
                 val=1234,
                 args=["title"],
                 kwargs={},
-                expect=FilterValueError,
+                expect=FilterArgumentError,
             ),
             Case(
                 description="missing argument",
@@ -652,15 +655,15 @@ class ArrayFilterTestCase(unittest.TestCase):
             ),
             Case(
                 description="unhashable items",
-                val=["a", "b", [], {}],
-                args=[", "],
+                val=["a", "b", [], {}, {}],
+                args=[],
                 kwargs={},
-                expect=FilterArgumentError,
+                expect=["a", "b", {}],
             ),
             Case(
                 description="unexpected argument",
                 val=["a", "b"],
-                args=[", "],
+                args=["foo", "bar"],
                 kwargs={},
                 expect=FilterArgumentError,
             ),
@@ -669,7 +672,7 @@ class ArrayFilterTestCase(unittest.TestCase):
                 val="a, b",
                 args=[],
                 kwargs={},
-                expect=FilterValueError,
+                expect=["a, b"],
             ),
             Case(
                 description="undefined left value",
@@ -712,7 +715,7 @@ class ArrayFilterTestCase(unittest.TestCase):
                 val=1,
                 args=[],
                 kwargs={},
-                expect=FilterValueError,
+                expect=[1],
             ),
             Case(
                 description="undefined left value",
